| c.std | R Documentation |
The function is used to concatenate more sievetest objects together.
## S3 method for class 'std'
c(...)
... |
one or more |
Returns one std object concatenated of objects supplied in ... containing all the sieve test samples grouped together.
read.std, std, summary.std
data(lignite)
# a and b simulate some new std objects
a <- lignite[2]
b <- lignite[1]
#
ab_group <- c(a,b)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.