| desc.std | R Documentation |
The function for querying a std object for description meta data
or creating new description meta data list.
desc.std(Description = NA,
Title = NA,
Sample = NA,
Unit = NA,
Date = NA,
x = NULL)
Description |
Terse description of a sample |
Title |
Title of particular measurement |
Sample |
Name of the sample |
Unit |
To which unit the sample belongs |
Date |
Day when the sample was taken |
x |
An existing |
To be used for creating input for desc argument in functions
std and tweak.std.
Returns a list of 5:
Description |
|
Title |
|
Sample |
|
Unit |
|
Date |
std
# create the object by hand
# sieve test data (std) object
my_sample <- std(
a=c(500, 200, 90, 0),
r=c(1.01, 24, 42.8, 32.190),
desc=desc.std(Title="Coal powder, learning std")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.