| lignite | R Documentation |
This is example std object, which is used in examples and in demo code. It is based on sieve test results of powdered lignite.
data(lignite)
data(lignite)
str(lignite)
summary(lignite)
plot(lignite)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.